---
id: revolutionizing_data_center
title: "Revolutionizing Data Center Design: Exploring Tier S"
image_caption: "Revolutionizing Data Center Design: Exploring Tier S"
description: The Tier S model is designed to exceed the capabilities of traditional data centers...
date: 2024-02-10
taxonomies:
  tags: []
  categories: []
extra:
  imgPath: revolutionizing_data_center.png
---
In an era where artificial intelligence is reshaping our technological landscape, it is imperative to reconsider how we design and operate data centers. With decades of experience in the Internet and Cloud space and in response to technological evolutions, ThreeFold is proposing a new approach.

<br>

Over the last 30 years, data center construction has largely remained static. Contemporary data centers risk becoming obsolete if they continue to neglect evolving needs. As we stand at this technological crossroads, the urgency to adapt is clear: unless we pay close attention, new data centers risk repeating the inefficiencies of their predecessors, leading to a poor utilization of investments and a significant mismatch with current and future requirements.

## The Two Main Flaws of Existing Data Centers

### Inadequate Power Provision

The advent of AI has dramatically escalated power needs. An AI-centric rack can consume up to 200 kW – a staggering 15 times more than the capacity of data centers built in the conventional model. This exponential increase poses significant challenges, particularly when dissipation exceeds 50 kW per rack. Traditional designs fall short in crucial aspects like cooling and power distribution, with conventional air cooling methods becoming increasingly unviable.

### The Shift in Market Needs: Beyond Co-location

The market dynamics have evolved; selling space in a data center, akin to ‘advanced real estate’, is a model that is rapidly losing relevance. The traditional co-location framework, which expects customers to manage their hardware and infrastructure within leased rack space, is becoming antiquated.

<br>

In the modern landscape, the role of a data center should transcend mere space rental. The emphasis should be on providing integrated solutions – selling compute, storage, and network capacity, not just rackspace and power. It’s about delivering a comprehensive service that aligns with the complex, ever-evolving needs of businesses immersed in the digital and AI revolution.

## The Data Center Landscape Today

Tier 3 and Tier 4 Data Centers are classifications outlined by the Uptime Institute, which provide standards for the design, construction, and operation of data centers. The Institute defines four tiers (1, 2, 3, & 4) to categorize data centers according to their design and infrastructure capabilities. For the purposes of this article, we will focus on the top two tiers.

### Tier 3

A Tier 3 Data Center is a type of data center facility that is designed to provide a high level of availability and redundancy for IT infrastructure and data storage.

<br>

#### Key Characteristics

- Availability: Tier 3 Data Centers typically offer 99.982% availability, translating to around 1.6 hours of downtime per year.
- Redundancy: They feature N+1 redundancy for power and cooling systems, providing backup components to ensure continuous operation in case of failure.
- Concurrent Maintenance: Tier 3 Data Centers allow for maintenance and repairs to be performed on systems without disrupting operations.
- Cost: Tier 3 Data Centers are less expensive to build and operate compared to Tier 4 due to lower redundancy requirements.

It's important to note that while Tier 3 Data Centers provide a high level of availability and redundancy, they are not as robust as Tier 4 Data Centers, which are designed to provide even higher levels of fault tolerance and uptime. The choice of data center tier depends on the specific needs and risk tolerance of the organization using the facility.

#### Key Challenges

- Limited Uptime: Despite high reliability, Tier 3 Data Centers may still experience noticeable downtime, which could impact critical operations.
- Single Points of Failure: While designed for redundancy, Tier 3 Data Centers may still have single points of failure, potentially leading to downtime during component failures.
- Scalability: They may have limitations in scalability compared to higher tier data centers, potentially requiring more significant upgrades for expansion.

<br>

When a business is considering colocation or hosting in a Tier 3 Data Center, it's important to assess its power requirements carefully. For operations with high power demands, it might be necessary to discuss with the data center provider the possibilities of allocating additional power resources or choosing a high-density zone within the data center. Data center providers typically measure power in kilowatts (kW) per rack and will have different pricing models based on the power and cooling requirements of the equipment hosted.

### Tier 4

A Tier 4 Data Center is the most advanced type of data center tier, as classified by the Uptime Institute. The Tier 4 Data Center is the most robust and less prone to failures. Its design ensures redundancy and reliability.

#### Key Characteristics

- Availability: Tier 4 Data Centers offer the highest level of availability, typically guaranteeing 99.995% uptime or just around 26.3 minutes of downtime per year.
- Fault Tolerance: They feature a fault-tolerant design with 2N+1 redundancy for critical systems, ensuring uninterrupted operation even during component failures.
- Redundancy: Tier 4 Data Centers have redundant power and cooling distribution paths, eliminating single points of failure.
- Security: They often have advanced security measures in place, including biometric access controls and surveillance systems.

#### Key Challenges

- Complexity: Tier 4 Data Centers are more complex and expensive to design, build, and maintain due to their fault-tolerant architecture.
- High Cost: The increased redundancy and fault tolerance come with higher costs, making Tier 4 Data Centers more expensive to operate compared to lower tiers.
- Overkill for Some Applications: For organizations with less critical operations or smaller budgets, Tier 4 Data Centers may be overkill and not cost-effective.

### Choosing Between Tier 3 and Tier 4

- Cost vs. Need: Tier 4 Data Centers are significantly more expensive to build and operate. Organizations should assess whether they need the highest level of uptime and fault tolerance that Tier 4 provides.
- Business Requirements: Businesses that can afford occasional downtimes for maintenance or those that don't have extremely critical data operations may find Tier 3 facilities adequately sufficient.
- Industry Compliance: Certain industries may require or favor Tier 4 facilities due to regulatory requirements.

<br>

In summary, while both Tier 3 and Tier 4 Data Centers are designed to ensure high levels of uptime and reliability, Tier 4 takes this a step further with increased redundancy, fault tolerance, and a correspondingly higher price point.

## Introducing the Tier S Data Center

The Tier S model is designed to exceed the capabilities of traditional Tier 3 and 4 Data Centers, addressing the increasing demand for infrastructure that can support emerging IT workloads with greater efficiency and resilience. Where "S" stands for "Self-Healing," Tier S Data Centers present a new way forward, while remaining backwards compatible.

<br>

The Tier S "circular approach" allows us to build the most reliable and redundant data centers in the world. A larger data center (typically 2-10 mW capacity) is extended with at least nine edge data centers. Key features include advanced liquid cooling technology and cybersecurity mechanisms, enhancing the center's ability to handle complex IT workloads like AI and ML.

<br>

Flexibility is central to the design, with each edge data center capable of housing 3-30 pods (subsections), and a versatile main data center. The innovative self-healing technology ensures continuous, secure operations, reducing downtime and maintenance needs. The infrastructure, integrating state-of-the-art hydro coolant distribution units, is designed for high-performance computing, meeting emerging technological demands.

### Key Benefits

- Superior Reliability: Data storage is highly secure and can't be lost, would even be safe if quantum computing would be used for hacking.
- 100% Redundancy: Fully redundant power and network paths. All hardware is equipped with liquid cooling for enhanced reliability and energy-efficiency..
- Capacity and Expansion: A main data center with a 2-10 MW capacity, supplemented by at least 9 edge data centers.
- Flexible Configuration: Each edge data center can include 3 to 30 pods (more information below), with the main data centers configurable as pod, rack, or container-based.
- Disaster Resilience: The circular design, with a main data center and edge data centers, offers robust protection against natural disasters, war, or unrest.
- Self-Healing: Equipped with self-healing properties, Tier S Data Centers ensure that workloads can operate safely with minimal need for human intervention.

## In Conclusion

The existing data center model is simply insufficient for emerging demands of the IT world. Billions of dollars will be mis-spent if we continue down the existing path. This is why ThreeFold is presenting a new approach. While the Tier S Data Center is still in its conceptual phase, we are actively working with partners on implementing the first of its kind in the near future.